Documentation
¶
Overview ¶
Package framework provides a test framework for E2E tests. nolint: gosec // warnings relating to executing commands and reading files from variables not important in these tests
Index ¶
Constants ¶
const ( // BYOAGC is placeholder value to use for a BYO AGC resource BYOAGC = "" /* 141-byte string literal not displayed */ // ManagedSubnet is a placeholder of a subnet ID to use for managed scenarios ManagedSubnet = "" /* 153-byte string literal not displayed */ )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TestCase ¶
type TestCase struct {
// input files for the migration tool
InputFiles []string
ExtraFiles []string // these are extra resources to be applied to the cluster, but not part of the migration input
ParentDir string
// expected resources after migration
ExpectedResources resources.AGCResourceGraph
// expected report after migration
ExpectedReport reporting.MigrationReport
}
func NewTestCase ¶
func (TestCase) RunMigration ¶
func (tc TestCase) RunMigration(t *testing.T, flags ...string) (reporting.MigrationReport, resources.AGCResourceGraph, string)
Click to show internal directories.
Click to hide internal directories.